#ASReml analysis script for 'IS PAIRING WITH A RELATIVE HERITABLE? ESTIMATING FEMALE AND MALE GENETIC CONTRIBUTIONS TO THE DEGREE OF BIPARENTAL INBREEDING IN SONG SPARROWS (Melospiza melodia)' Wolak & Reid, American Naturalist 2016

#This file contains the R code required for the quantitative genetic analyses of the degree to which individuals inbreed through social pairing in relation to the female and male's own coefficients of inbreeding and genetic effects stemming from immigration. Please use the accompanying files "WolakReid_data.txt" and "WolakReid_listAinv.txt" for the R analyses.

#These data come from the long-term song sparrow field study on Mandarte Island, BC, Canada.
#The data provided here are sufficient to replicate the analyses presented in the above paper, and are therefore a restricted subset of the full Mandarte dataset.
#If you are interested in running further analyses that require further data then please get in touch with
#Prof Peter Arcese (University of British Columbia), Prof Lukas Keller (University of Zurich) or Prof Jane Reid (University of Aberdeen).
#We are always happy to develop collaborations with researchers who have good ideas for new analyses.
#We'd also appreciate it if you could let us know if you are intending to make use of the dataset below in order to facilitate coordination of different ongoing research efforts and allow us to keep track of all outputs from the long-term field study.

################################################################################rm(list = ls())
setwd("<Directory containing data and Ainverse files>")

#Load required libraries
library(MCMCglmm)   # necessary for the `at.level()` function in fixed effects
library(nadiv)
library(asreml)

# Load the data
datin <- read.table("WolakReid_data.txt", header = TRUE)
# Create factors
## codes for femaleIS and maleIS:
## Immigrant==1 and Resident==2
datin$maleIS <- as.factor(datin$maleIS)
datin$femaleIS <- as.factor(datin$femaleIS)
datin$female <- as.factor(datin$female)
datin$male <- as.factor(datin$male)
datin$femaleID <- as.factor(datin$femaleID)
datin$maleID <- as.factor(datin$maleID)
datin$year <- as.factor(datin$year)


# Load inverse A matrix
listAinv <- read.table("WolakReid_listAinv.txt", header = TRUE)
  attr(listAinv, "rowNames") <- as.character(unique(listAinv[, 1]))



###############################################################################
####         MODEL		###
asMod <- asreml(ksoc ~ maleImm + femaleImm + at.level(maleIS, "2"):maleF + at.level(femaleIS, "2"):femaleF,
		random = ~ str(~ ped(female) + ped(male), ~ us(2):ped(female)) + femaleID + maleID + year, 
		ginverse = list(female = listAinv, male = listAinv),
		rcov = ~ idv(units),
		data = datin,
		maxiter = 100)
# Repeat/update model to overcome bad starting values
while(!pcc(asMod, silent = TRUE)) asMod <- update.asreml(asMod, maxiter = 100)





